//--------------------------------------------------------------
// File     : stm32_ub_icfrq_tim2.h
//--------------------------------------------------------------

//--------------------------------------------------------------
#ifndef __STM32F4_UB_ICFRQ_TIM2_H
#define __STM32F4_UB_ICFRQ_TIM2_H


//--------------------------------------------------------------
// Includes
//--------------------------------------------------------------
#include "stm32f4xx.h"
#include "stm32f4xx_gpio.h"
#include "stm32f4xx_rcc.h"
#include "stm32f4xx_tim.h"
#include "misc.h"







//--------------------------------------------------------------
// Liste aller InputCapture Pins (Frq-Messung)
// (keine Nummer doppelt und von 0 beginnend)
//--------------------------------------------------------------
typedef enum 
{
  ICFRQ_T2_PB11 = 0,  // FRQ-Messung per TIM2 an PB11
  ICFRQ_T2_PA2  = 1   // FRQ-Messung per TIM2 an PA2
}ICFRQ_TIM2_NAME_t;

#define  ICFRQ_TIM2_ANZ   2 // Anzahl von ICFRQ_TIM2_NAME_t




//--------------------------------------------------------------
// Input-Capture Einstellungen (Frequenz vom Timer2)
//
// Grundfrequenz = 2*APB1 (APB1=42MHz) => TIM_CLK=84MHz
// prescale  : 0 bis 0xFFFF
//
// T2_Frq = TIM_CLK/(vorteiler+1)
//--------------------------------------------------------------
#define  ICFRQ_TIM2_PRESCALE  83     // prescaler => (83 => T2_Frq = 1 MHz)



//--------------------------------------------------------------
// Struktur eines InputCapture Kanals (zur FRQ-Messung)
//--------------------------------------------------------------
typedef struct {
  ICFRQ_TIM2_NAME_t IC_NAME;   // Name
  const uint8_t CHANNEL;       // Channel [1...4]
  GPIO_TypeDef* IC_PORT;       // Port
  const uint16_t IC_PIN;       // Pin
  const uint32_t IC_CLK;       // Clock
  const uint8_t IC_SOURCE;     // Source
}ICFRQ_TIM2_t;


//--------------------------------------------------------------
// interne Struktur
//--------------------------------------------------------------
typedef struct {
  uint16_t flanke_nr; // Merker fr Flanke
  uint16_t wert0;     // Messwert bei 1ter Flanke
  uint16_t wert1;     // Messwert bei 2ter Flanke
  uint32_t wert;      // Differenz (zwischen zwei Flanken)
}ICFRQ_TIM2_Var_t;


//--------------------------------------------------------------
// Globale Funktionen
//--------------------------------------------------------------
void UB_ICFRQ_TIM2_Init(void);
uint32_t UB_ICFRQ_TIM2_ReadFRQ(ICFRQ_TIM2_NAME_t vname);




//--------------------------------------------------------------
#endif // __STM32F4_UB_ICFRQ_TIM2_H
